%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Cover Corporate Identity v1.1.0
%
% LaTeX class for letter style documents in Cover's Corporate Idenity
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cover-letter}[2016/08/28 Cover Letter]


\newcommand{\backgroundimage}{\AddToShipoutPicture{\includegraphics{assets/document_template_external}}}

\DeclareOption{external}{}
\DeclareOption{internal}{\renewcommand{\backgroundimage}{\AddToShipoutPicture{\includegraphics{assets/document_template_internal}}}}
\DeclareOption{internal-legal}{\renewcommand{\backgroundimage}{\AddToShipoutPicture{\includegraphics{assets/document_template_internal_legal}}}}
\DeclareOption{empty}{\renewcommand{\backgroundimage}{}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions\relax

\LoadClass[a4paper,10pt]{letter}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PDF Settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[colorlinks=false]{hyperref}

% No borders around links and set PDF application
\hypersetup{%
  pdfborder={0 0 0},
  pdfcreator={Cover Corporate Identity 0.1}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Page Settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[usenames,dvipsnames,svgnames,table]{xcolor}
\RequirePackage{graphicx}   % Images
\RequirePackage{eso-pic}    % Watermark
\RequirePackage[top=4cm,right=2.5cm,bottom=3.5cm,left=2.5cm]{geometry}
% Move letter to top
\let\@texttop\relax


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load fonts and characters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{mathpazo} % Load palatino
\linespread{1.05}         % Palatino needs more leading (space between lines)
\RequirePackage{FiraSans} % Load Fira as SS
\RequirePackage{FiraMono} % Load Fira as TT
\normalfont
\RequirePackage[T1]{fontenc}
\RequirePackage{parskip}

% Square

\RequirePackage{amsmath}

\DeclareFontFamily{U}{mathb}{}
\DeclareFontShape{U}{mathb}{m}{n}{
  <-5.5> mathb5
  <5.5-6.5> mathb6
  <6.5-7.5> mathb7
  <7.5-8.5> mathb8
  <8.5-9.5> mathb9
  <9.5-11.5> mathb10
  <11.5-> mathbb12
}{}
\DeclareRobustCommand{\sqcdot}{%
  \text{\,\usefont{U}{mathb}{m}{n}\symbol{"0D}}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Custom colors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% \definecolor{coverRed}{RGB}{200,16,46}
\definecolor{coverRed}{cmyk}{0.02,1,0.85,0.06}
% \definecolor{coverLG}{RGB}{218,218,218}
\definecolor{coverLG}{cmyk}{0,0,0,0.2}
% \definecolor{coverDG}{RGB}{102,102,102}
\definecolor{coverDG}{cmyk}{0,0,0,0.7}
% \definecolor{coverBlue}{RGB}{54,116,157}
\definecolor{coverBlue}{cmyk}{0.83, 0.39, 0.15, 0.13}
% \definecolor{coverGreen}{RGB}{0,173,80}
\definecolor{coverGreen}{cmyk}{0.87, 0.0, 0.91, 0.0}
% \definecolor{coverYellow}{RGB}{215,200,38}
\definecolor{coverYellow}{cmyk}{0.7, 0.1, 0.89, 0.10}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set background image
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\backgroundimage

\endinput
